require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

require 'flux/git'

describe "Flux::Git::Branch()" do
  G = Flux::Git
  B = G::Branch

  it "when passed a branch, returns the same branch" do
    G::Branch(B.current).should == B.current
  end

  it "converts a remote/branch/name string to a remote branch" do
    stub(G).repo('blah').stub!.remote_list { ['origin'] }

    a = B.remote('dl/something', 'origin', 'blah')
    b = G::Branch('origin/dl/something', 'blah')

    b.should == a
  end

  it "converts a branch/name string to a local branch" do
    stub(G).repo('blah').stub!.remote_list { ['origin'] }

    a = B.local('dl/something', 'blah')
    b = G::Branch('dl/something', 'blah')

    b.should == a
  end
end

describe Flux::Git::Branch do
  self::G = Flux::Git
  self::B = G::Branch

  it "determines whether it is rebased with another branch" do
    stub(G).repo('.').stub! {
      commits_between('my_branch', 'master') { [] }
      commits_between('my_branch', 'origin/my_branch') {
        ["commit_in_origin_my_branch"]
      }
    }

    a = B.local('my_branch', '.')
    b = B.remote('my_branch', 'origin', '.')
    c = B.local('master', '.')

    a.should include(c)
    a.should_not include(b)
  end
end
